@@ -311,7 +311,7 @@ class NS(hildon.Program):
         # set tree properties
         treeview.set_headers_visible(True)
         treeview.set_fixed_height_mode(False)
-        treeview.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
+#        treeview.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
 
 
     def on_next_clicked(self, button, list):
@@ -468,7 +468,7 @@ class NS(hildon.Program):
         # set tree properties
         treeview.set_headers_visible(True)
         treeview.set_fixed_height_mode(False)
-        treeview.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
+#        treeview.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
           
     def create_menu(self,label):
         menu = hildon.AppMenu()
